@@ -10,4 +10,5 @@ __all__ = [
 ]
 
 class PWManError(Exception):
-	pass
+	"""Main pwman exception.
+	"""
